@@ -138,102 +138,56 @@ Net::Cloudflare::DNS - DNS API for Cloudflare API v4
 
 =head1 VERSION
 
-Version 0.02
+Version 0.15
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.15';
 
 
 =head1 SYNOPSIS
 
-Cloudflare API v4 has big improvement to the older ones. This API operates against the specific zone based on API v4. 
+This perl module is working for Cloudflare DNS API v4.
 
-I use this module to dyna update my DNS zone everyday. Cloudflare's DNS and its API behave very well in my life.
+If you find any issues in using the module, please don't hesitate to email me: opensoft [at] posthub.me
 
-If you have met any issue with the module, please don't hesitate to drop me an email: iwesley [at] pobox.com
-
-To use the module, you must have these two perl modules installed in the system:
+My system is Ubuntu, to use the module, I have the following perl modules pre-installed in the system.
 
     sudo apt install libio-socket-ssl-perl
     sudo cpanm LWP::Protocol::https
 
-My system is Ubuntu, which can use apt to install IO::Socket::SSL. I can't install this module with cpanm tool.
+After then, you can run "cpanm Net::Cloudflare::DNS" to install this module.
 
+    use strict;
     use Net::Cloudflare::DNS;
+    use Data::Dumper;
+
+    my $api_key = " ";
+    my $zone_id = " ";
+    my $email = " ";
 
     # new the object
     my $dns = Net::Cloudflare::DNS->new(email=>$email, api_key=>$api_key, zone_id=>$zone_id);
+    my $res;
 
-    # create the record
-    my $res = $dns->create_record(type=>"A", name=>"test.myhostnames.com",content=>"1.1.1.1",ttl=>1);
+    # create record
+    $res = $dns->create_record(type=>"A", name=>"www.simplemail.co.in", content=>"74.81.81.81", proxied=>\1, ttl=>60);
 
-    # update the record
-    $res = $dns->update_record($record_id, type=>"TXT", name=>"test.myhostnames.com",content=>"bala bala",ttl=>1);
-
-    # delete the record
-    $res = $dns->delete_record($record_id);
-
-    # list records by conditions
-    $res = $dns->get_records(name=>"test.myhostnames.com");
-
-    # if the method succeed, a structure reference was returned, whose content is response content from cloudflare 
-    # otherwise the method just dies, you should catch the error in your code
-    use Data::Dumper;
-    print Dumper $res;
-
-Hence this is my own script for test purpose:
-
-    use strict;
-    use warnings;
-    use Net::Cloudflare::DNS;
-
-    my $obj = Net::Cloudflare::DNS->new(email    => $ENV{'CLOUDFLARE_EMAIL'},
-                                        api_key  => $ENV{'CLOUDFLARE_API_KEY'},
-                                        zone_id  => $ENV{'CLOUDFLARE_ZONE_ID'},
-                                       );
-
-    #
-    # batch add
-    #
-    for (1..10) {
-        my $rand_hostname = int(rand(3333333)) . ".myhostnames.com";
-        my $rand_ip = int(rand(255)) ."." . int(rand(255)). ".". int(rand(255)). ".". int(rand(255));
-
-        $obj->create_record(type=>"A", name=>$rand_hostname,content=>$rand_ip,ttl=>1);
-    }
-
-    #
     # get records
-    #
-    my @records;
+    $res = $dns->get_records(name=>"www.simplemail.co.in");
 
-    my $ref = $obj->get_records('per_page'=>100);
-    my @rr = @{$ref->{result}};
+    # parse record id
+    my $rid = $res->{result}->[0]->{id};
 
-    for (@rr) {
-        if ($_->{name} =~ /^\d+/) {
-          push @records, [$_->{id}, $_->{name}]; 
-        }
-    }
+    # update record
+    $res = $dns->update_record($rid, type=>"A", name=>"www.simplemail.co.in",content=>"52.1.14.22", proxied=>\0, ttl=>60);
 
-    #
-    # batch update
-    #
-    for  (@records) {
-        my $id = $_->[0];
-        my $hostname = $_->[1];
-        my $rand_ip = int(rand(255)) ."." . int(rand(255)). ".". int(rand(255)). ".". int(rand(255));
+    # delete record
+    $res = $dns->delete_record($rid);
 
-        $obj->update_record($id, type=>"A", name=>$hostname,content=>$rand_ip,ttl=>1);
-    }
-
-    #
-    # batch delete
-    #
-    for  (@records) {
-        $obj->delete_record($_->[0]);
-    }
+    # If it success, cloudflare's response is just resturned as a reference to you.
+    # Otherwise the method just dies, you should catch the error in the code.
+    print Dumper $res;
 
 
 =head1 SUBROUTINES/METHODS
@@ -242,7 +196,7 @@ Hence this is my own script for test purpose:
 
     my $dns = Net::Cloudflare::DNS->new(email=>$email, api_key=>$api_key, zone_id=>$zone_id);
 
-You have to provide 3 arguments to new() method. One is your registration email on Cloudflare. Another is your API Key, which can be 
+You have to provide 3 arguments to new() method. The first is your registration email on Cloudflare. The second is your API Key, which can be 
 found on Cloudflare's management panel ("Global API Key"). The last is Zone ID, each zone has the unique ID, which can be found
 on zone's page.
 
@@ -250,64 +204,60 @@ Please notice: You must enable zone edit permissions for this API. In management
 chance to setup permissions for the zone, with which you can edit zone's DNS records. 
  
 
-
 =head2 create_record
 
-    my $res = $dns->create_record(type=>"A", name=>"test.myhostnames.com",content=>"1.1.1.1",ttl=>1);
+    my $res = $dns->create_record(type=>"A", name=>"www.simplemail.co.in",content=>"1.2.3.4",proxied=>\1,ttl=>1);
 
-You can create record in the zone with this method.
+Create record in the zone.
 
-Required parameters:
+You have to provide the following parameters.
 
-type: includes "A", "TXT", "MX", "CNAME" ... They are standard DNS record type.
+type: includes "A", "TXT", "MX", "CNAME" ... They are standard DNS record types.
 
-name: the hostname you want to create, must be FQDN.
+name: the hostname you want to create, such as www.
 
-content: record's value, for "A" record, it's an IP address.
+content: record value, for "A" record, it's an IP address.
 
-ttl: time to live. You can always set it to 1, which means automatic by Cloudflare. otherwise it's must be larger than 120.
+ttl: time to live. You can set it to 1, which means to be automated by Cloudflare.
 
 Optional parameters:
 
-priority: MX's priority, default 0.
+priority: MX priority, default 0.
 
-proxied: whether proxied by cloudflare, default false.
+proxied: whether proxied by cloudflare, it's either \1 (true) or \0 (false).
 
-Please read the official documentation here:
-
-    https://api.cloudflare.com/#dns-records-for-a-zone-properties
+Please read their official documentation below.
 
+    https://developers.cloudflare.com/api/#dns-records-for-a-zone-properties
 
 
 =head2 update_record
 
-    $res = $dns->update_record($record_id, type=>"TXT", name=>"test.myhostnames.com",content=>"bala bala",ttl=>1);
+    $res = $dns->update_record($record_id, type=>"TXT", name=>"www.simplemail.co.in",content=>"bala bala",ttl=>1);
 
-Update the record in the zone.
+Update record in the zone.
 
-You must provide $record_id as the first argument, the left arguments are almost the same with create_record method.
+Please provide $record_id as the first argument, the rest are almost the same as create_record.
 
 You can get $record_id from get_records method.
 
 
-
 =head2 delete_record
 
     $res = $dns->delete_record($record_id);
 
-Delete the record in the zone.
-
-You must provide $record_id as the unique argument.
+Delete record from the zone.
 
+Provide $record_id as the unique argument.
 
 
 =head2 get_records
 
     $res = $dns->get_records(conditions...);
 
-List the records by conditions. For details you can read the documentation:
+List records by conditions. For details please read the following documentation.
 
-    https://api.cloudflare.com/#dns-records-for-a-zone-properties
+    https://developers.cloudflare.com/api/#dns-records-for-a-zone-properties
 
 
 
